@@ -3,8 +3,8 @@
 ;; Copyright (C) 2024-2026 James Cherti | https://www.jamescherti.com/contact/
 
 ;; Author: James Cherti <https://www.jamescherti.com/contact/>
-;; Package-Version: 20260215.2013
-;; Package-Revision: 2e833ba5b799
+;; Package-Version: 20260219.1823
+;; Package-Revision: 7c876e3f3faf
 ;; URL: https://github.com/jamescherti/vim-tab-bar.el
 ;; Keywords: frames
 ;; Package-Requires: ((emacs "28.1"))
@@ -58,7 +58,9 @@
   "Non-nil if vim-tab-bar mode mode is enabled."
   :group 'vim-tab-bar
   :prefix "vim-tab-bar-"
-  :link '(url-link "https://github.com/jamescherti/vim-tab-bar.el"))
+  :link '(url-link
+          :tag "Github"
+          "https://github.com/jamescherti/vim-tab-bar.el"))
 
 (defcustom vim-tab-bar-format-tabs-groups
   '(tab-bar-format-tabs-groups tab-bar-separator)
